@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io1200.h,v 1.5 2004/11/01 21:19:54 arcanum Exp $ */
+/* $Id: io1200.h,v 1.8.4.3 2008/08/14 00:07:59 arcanum Exp $ */
 
 /* avr/io1200.h - definitions for AT90S1200 */
 
@@ -72,7 +72,15 @@
 
 /* 0x19..0x1B reserved */
 
-/* 0x1C..0x1E EEPROM */
+/* EEPROM Control Register */
+#define EECR	_SFR_IO8(0x1C)
+
+/* EEPROM Data Register */
+#define EEDR	_SFR_IO8(0x1D)
+
+/* EEPROM Address Register */
+#define EEAR	_SFR_IO8(0x1E)
+#define EEARL	_SFR_IO8(0x1E)
 
 /* 0x1F..0x20 reserved */
 
@@ -106,9 +114,17 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0		_VECTOR(1)
-#define SIG_OVERFLOW0		_VECTOR(2)
-#define SIG_COMPARATOR		_VECTOR(3)
+/* External Interrupt 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect			_VECTOR(2)
+#define SIG_OVERFLOW0			_VECTOR(2)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(3)
+#define SIG_COMPARATOR			_VECTOR(3)
 
 #define _VECTORS_SIZE 8
 
@@ -216,12 +232,39 @@
 #define ACIS1	1
 #define ACIS0	0
 
+/* EEPROM Control Register */
+#define EERIE	3
+#define EEMWE	2
+#define EEWE	1
+#define EERE	0
+
 #undef ZH
 
 /* Last memory addresses */
 #define RAMEND		0x1F
 #define XRAMEND		0x0
 #define E2END		0x3F
+#define E2PAGESIZE  0
 #define FLASHEND	0x3FF
 
+
+/* Fuses */
+#define FUSE_MEMORY_SIZE 1
+
+/* Low Fuse Byte */
+#define FUSE_RCEN  (unsigned char)~_BV(0)
+#define FUSE_SPIEN (unsigned char)~_BV(5)
+#define LFUSE_DEFAULT (0xFF)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+
+
+/* Signature */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x90
+#define SIGNATURE_2 0x01
+
+
 #endif  /* _AVR_IO1200_H_ */
