@@ -27,12 +27,13 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: fputc.c,v 1.3 2005/09/06 18:49:15 joerg_wunsch Exp $ */
+/* $Id: fputc.c,v 1.3.4.1 2009/04/01 23:11:58 arcanum Exp $ */
 
 #include <stdio.h>
-
+#include "sectionname.h"
 #include "stdio_private.h"
 
+ATTRIBUTE_CLIB_SECTION
 int
 fputc(int c, FILE *stream)
 {
