@@ -27,13 +27,14 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: fputs_p.c,v 1.5 2005/09/06 18:49:15 joerg_wunsch Exp $ */
+/* $Id: fputs_p.c,v 1.5.4.1 2009/04/01 23:11:58 arcanum Exp $ */
 
 #include <stdio.h>
 #include <avr/pgmspace.h>
-
+#include "sectionname.h"
 #include "stdio_private.h"
 
+ATTRIBUTE_CLIB_SECTION
 int
 fputs_P(const char *str, FILE *stream)
 {
