@@ -27,12 +27,14 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: snprintf.c,v 1.1.8.1 2007/03/25 14:31:27 dmix Exp $ */
+/* $Id: snprintf.c,v 1.2.2.1 2009/04/01 23:12:00 arcanum Exp $ */
 
 #include <limits.h>
 #include <stdarg.h>
 #include <stdio.h>
+#include "sectionname.h"
 
+ATTRIBUTE_CLIB_SECTION
 int
 snprintf(char *s, size_t n, const char *fmt, ...)
 {
