@@ -26,13 +26,14 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: vfprintf_p.c,v 1.1 2003/10/16 20:39:48 troth Exp $ */
+/* $Id: vfprintf_p.c,v 1.1.10.1 2009/04/01 23:12:06 arcanum Exp $ */
 
 #include <stdarg.h>
 #include <stdio.h>
-
+#include "sectionname.h"
 #include "stdio_private.h"
 
+ATTRIBUTE_CLIB_SECTION
 int
 vfprintf_P (FILE *stream, const char *fmt, va_list ap)
 {
