@@ -27,14 +27,15 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vsprintf.c,v 1.1 2003/11/12 20:50:03 joerg_wunsch Exp $ */
+/* $Id: vsprintf.c,v 1.1.10.1 2009/04/01 23:12:07 arcanum Exp $ */
 
 #include <limits.h>
 #include <stdarg.h>
 #include <stdio.h>
-
+#include "sectionname.h"
 #include "stdio_private.h"
 
+ATTRIBUTE_CLIB_SECTION
 int
 vsprintf(char *s, const char *fmt, va_list ap)
 {
