@@ -30,10 +30,10 @@
 */
  
  
-/* $Id: malloc.c,v 1.10 2004/10/29 16:26:47 arcanum Exp $ */
+/* $Id: malloc.c,v 1.11.4.2 2009/04/01 23:12:11 arcanum Exp $ */
 
 #include <stdlib.h>
-
+#include "sectionname.h"
 #include "stdlib_private.h"
 
 #ifdef MALLOC_TEST
@@ -62,6 +62,7 @@ char *__malloc_heap_end = &__heap_end;
 char *__brkval;
 struct __freelist *__flp;
 
+ATTRIBUTE_CLIB_SECTION
 void *
 malloc(size_t len)
 {
@@ -169,12 +170,17 @@ malloc(size_t len)
 	cp = __malloc_heap_end;
 	if (cp == 0)
 		cp = STACK_POINTER() - __malloc_margin;
+	if (cp <= __brkval)
+	  /*
+	   * Memory exhausted.
+	   */
+	  return 0;
 	avail = cp - __brkval;
 	/*
 	 * Both tests below are needed to catch the case len >= 0xfffe.
 	 */
 	if (avail >= len && avail >= len + sizeof(size_t)) {
-		fp1 = (struct freelist *)__brkval;
+		fp1 = (struct __freelist *)__brkval;
 		__brkval += len + sizeof(size_t);
 		fp1->sz = len;
 		return &(fp1->nx);
@@ -185,6 +191,8 @@ malloc(size_t len)
 	return 0;
 }
 
+
+ATTRIBUTE_CLIB_SECTION
 void
 free(void *p)
 {
