@@ -27,13 +27,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: strtol.c,v 1.3 2005/01/25 10:37:50 joerg_wunsch Exp $
+ * $Id: strtol.c,v 1.3.4.1 2009/04/01 23:12:12 arcanum Exp $
  */
 
 #include <limits.h>
 #include <ctype.h>
 #include <errno.h>
 #include <stdlib.h>
+#include "sectionname.h"
 
 /*
  * Convert a string to a long integer.
@@ -41,11 +42,9 @@
  * Ignores `locale' stuff.  Assumes that the upper and lower case
  * alphabets and digits are each contiguous.
  */
+ATTRIBUTE_CLIB_SECTION
 long
-strtol(nptr, endptr, base)
-	const char *nptr;
-	char **endptr;
-	register int base;
+strtol(const char *nptr, char **endptr, register int base)
 {
 	register unsigned long acc;
 	register unsigned char c;
